@@ -506,6 +506,16 @@ impl HasByteSource for PublicAsymmetricKey {
     }
 }
 
+impl HasAlgorithmIdentifier for PublicAsymmetricKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        match self {
+            PublicAsymmetricKey::SodiumOxideCurve25519(k) => k.algorithm_identifier(),
+            PublicAsymmetricKey::SodiumOxideEd25519(k) => k.algorithm_identifier(),
+            PublicAsymmetricKey::RingEd25519(k) => k.algorithm_identifier(),
+        }
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Copy, Clone)]
 #[serde(tag = "t", content = "c")]
 pub enum PublicAsymmetricKeyBuilder {
@@ -608,6 +618,236 @@ impl HasByteSource for SecretAsymmetricKey {
     }
 }
 
+#[derive(Serialize, Deserialize, Debug)]
+pub enum SigningKey {
+    SodiumOxideEd25519(SodiumOxideEd25519SecretAsymmetricKey),
+    RingEd25519(RingEd25519SecretAsymmetricKey),
+}
+
+impl StorableType for SigningKey {}
+
+#[derive(Serialize, Deserialize, Debug)]
+pub enum EncryptingKey {
+    SodiumOxideCurve25519(SodiumOxideCurve25519SecretAsymmetricKey),
+    SodiumOxideSymmetricKey(SodiumOxideSymmetricKey),
+}
+
+impl StorableType for EncryptingKey {}
+
+#[derive(Serialize, Deserialize, Debug, Copy, Clone)]
+pub enum SigningKeyBuilder {
+    SodiumOxideEd25519(SodiumOxideEd25519SecretAsymmetricKeyBuilder),
+    RingEd25519(RingEd25519SecretAsymmetricKeyBuilder),
+}
+
+#[derive(Serialize, Deserialize, Debug, Copy, Clone)]
+pub enum EncryptingKeyBuilder {
+    SodiumOxideCurve25519(SodiumOxideCurve25519SecretAsymmetricKeyBuilder),
+    SodiumOxideSymmetricKey(SodiumOxideSymmetricKeyBuilder),
+}
+
+impl HasIndex for SigningKey {
+    type Index = Document;
+
+    fn get_index() -> Option<Self::Index> {
+        Some(bson::doc! {
+        "c": {
+            "builder": {
+        "t": "Key",
+        "c": {
+            "t": "Asymmetric",
+        "c": {
+        "t": "Secret"
+        }
+        }
+            }
+        }
+            })
+    }
+}
+
+impl HasIndex for EncryptingKey {
+    type Index = Document;
+
+    fn get_index() -> Option<Self::Index> {
+        Some(bson::doc! {
+        "c": {
+            "builder": {
+                "t": "Key"
+            }
+        }
+            })
+    }
+}
+
+impl HasBuilder for SigningKey {
+    type Builder = SigningKeyBuilder;
+
+    fn builder(&self) -> Self::Builder {
+        match self {
+            SigningKey::SodiumOxideEd25519(sosak) => {
+                SigningKeyBuilder::SodiumOxideEd25519(sosak.builder())
+            },
+            SigningKey::RingEd25519(rsak) => {
+                SigningKeyBuilder::RingEd25519(rsak.builder())
+            }
+        }
+    }
+}
+
+impl HasBuilder for EncryptingKey {
+    type Builder = EncryptingKeyBuilder;
+
+    fn builder(&self) -> Self::Builder {
+        match self {
+            EncryptingKey::SodiumOxideCurve25519(sosak) => {
+                EncryptingKeyBuilder::SodiumOxideCurve25519(sosak.builder())
+            },
+            EncryptingKey::SodiumOxideSymmetricKey(ssk) => {
+                EncryptingKeyBuilder::SodiumOxideSymmetricKey(ssk.builder())
+            }
+        }
+    }
+}
+
+impl TryFrom<TypeBuilderContainer> for SigningKeyBuilder {
+    type Error = CryptoError;
+
+    fn try_from(builder: TypeBuilderContainer) -> Result<Self, Self::Error> {
+        match builder.0 {
+            TypeBuilder::Key(KeyBuilder::Asymmetric(AsymmetricKeyBuilder::Secret(SecretAsymmetricKeyBuilder::SodiumOxideEd25519(sosak)))) => {
+                Ok(SigningKeyBuilder::SodiumOxideEd25519(sosak))
+            },
+            TypeBuilder::Key(KeyBuilder::Asymmetric(AsymmetricKeyBuilder::Secret(SecretAsymmetricKeyBuilder::RingEd25519(rsak)))) => {
+                Ok(SigningKeyBuilder::RingEd25519(rsak))
+            }
+            _ => Err(CryptoError::NotDowncastable),
+        }
+    }
+}
+
+impl TryFrom<TypeBuilderContainer> for EncryptingKeyBuilder {
+    type Error = CryptoError;
+
+    fn try_from(builder: TypeBuilderContainer) -> Result<Self, Self::Error> {
+        match builder.0 {
+            TypeBuilder::Key(KeyBuilder::Asymmetric(AsymmetricKeyBuilder::Secret(SecretAsymmetricKeyBuilder::SodiumOxideCurve25519(sosak)))) => {
+                Ok(EncryptingKeyBuilder::SodiumOxideCurve25519(sosak))
+            },
+            TypeBuilder::Key(KeyBuilder::Symmetric(SymmetricKeyBuilder::SodiumOxide(ssk))) => {
+                Ok(EncryptingKeyBuilder::SodiumOxideSymmetricKey(ssk))
+            }
+            _ => Err(CryptoError::NotDowncastable),
+        }
+    }
+}
+
+impl From<SigningKeyBuilder> for TypeBuilder {
+    fn from(skb: SigningKeyBuilder) -> TypeBuilder {
+        match skb {
+            SigningKeyBuilder::SodiumOxideEd25519(b) => b.into(),
+            SigningKeyBuilder::RingEd25519(b) => b.into(),
+        }
+    }
+}
+
+impl From<EncryptingKeyBuilder> for TypeBuilder {
+    fn from(ekb: EncryptingKeyBuilder) -> TypeBuilder {
+        match ekb {
+            EncryptingKeyBuilder::SodiumOxideCurve25519(b) => b.into(),
+            EncryptingKeyBuilder::SodiumOxideSymmetricKey(b) => b.into(),
+        }
+    }
+}
+
+impl Builder for SigningKeyBuilder {
+    type Output = SigningKey;
+
+    fn build(&self, bytes: Option<&[u8]>) -> Result<Self::Output, CryptoError> {
+        match self {
+            Self::SodiumOxideEd25519(sk) => Ok(SigningKey::SodiumOxideEd25519(sk.build(bytes)?)),
+            Self::RingEd25519(rk) => Ok(SigningKey::RingEd25519(rk.build(bytes)?)),
+        }
+    }
+}
+
+impl Builder for EncryptingKeyBuilder {
+    type Output = EncryptingKey;
+
+    fn build(&self, bytes: Option<&[u8]>) -> Result<Self::Output, CryptoError> {
+        match self {
+            Self::SodiumOxideCurve25519(sk) => Ok(EncryptingKey::SodiumOxideCurve25519(sk.build(bytes)?)),
+            Self::SodiumOxideSymmetricKey(sk) => Ok(EncryptingKey::SodiumOxideSymmetricKey(sk.build(bytes)?)),
+        }
+    }
+}
+
+impl Signer for SigningKey {
+    fn sign(&self, bytes: ByteSource) -> Result<ByteSource, CryptoError> {
+        match self {
+            SigningKey::SodiumOxideEd25519(k) => {
+                k.sign(bytes)
+            },
+            SigningKey::RingEd25519(k) => {
+                k.sign(bytes)
+            }
+        }
+
+    }
+}
+
+impl HasAlgorithmIdentifier for SigningKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        match self {
+            SigningKey::SodiumOxideEd25519(k) => {
+                k.algorithm_identifier()
+            },
+            SigningKey::RingEd25519(k) => {
+                k.algorithm_identifier()
+            }
+        }
+    }
+}
+
+impl HasByteSource for SigningKey {
+    fn byte_source(&self) -> ByteSource {
+        match self {
+            SigningKey::SodiumOxideEd25519(k) => {
+                k.byte_source()
+            },
+            SigningKey::RingEd25519(k) => {
+                k.byte_source()
+            }
+        }
+    }
+}
+
+impl HasByteSource for EncryptingKey {
+    fn byte_source(&self) -> ByteSource {
+        match self {
+            EncryptingKey::SodiumOxideSymmetricKey(k) => {
+                k.byte_source()
+            },
+            EncryptingKey::SodiumOxideCurve25519(k) => {
+                k.byte_source()
+            }
+        }
+    }
+}
+
+impl HasPublicKey for SigningKey {
+    type PublicKey = PublicAsymmetricKey;
+
+    fn public_key(&self) -> Result<Self::PublicKey, CryptoError> {
+        match self {
+            SigningKey::SodiumOxideEd25519(k) =>
+                Ok(PublicAsymmetricKey::SodiumOxideEd25519(k.public_key()?)),
+            SigningKey::RingEd25519(k) =>
+                Ok(PublicAsymmetricKey::RingEd25519(k.public_key()?))
+        }
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Copy, Clone)]
 #[serde(tag = "t", content = "c")]
 pub enum SecretAsymmetricKeyBuilder {
